@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Schema.pm 1528 2008-04-14T01:08:40.114508Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Schema.pm 1578 2008-05-10T01:30:21.225794Z claco  $
 package Mango::Schema;
 use strict;
 use warnings;
@@ -6,7 +6,10 @@ use warnings;
 BEGIN {
     use base qw/DBIx::Class::Schema/;
 
+    use Mango;
     use Mango::Exception ();
+
+    our $VERSION = Mango->VERSION;
 }
 __PACKAGE__->load_classes;
 
